==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/DpmContainerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.DpmContainerArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.BackupManagementType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * DPM workload-specific protection container.
 * @property backupManagementType Type of backup management for the container.
 * @property canReRegister Specifies whether the container is re-registrable.
 * @property containerId ID of container.
 * @property containerType Type of the container. The value of this property for: 1. Compute Azure VM is Microsoft.Compute/virtualMachines 2.
 * Classic Compute Azure VM is Microsoft.ClassicCompute/virtualMachines 3. Windows machines (like MAB, DPM etc) is
 * Windows 4. Azure SQL instance is AzureSqlContainer. 5. Storage containers is StorageContainer. 6. Azure workload
 * Backup is VMAppContainer
 * Expected value is 'DPMContainer'.
 * @property dpmAgentVersion Backup engine Agent version
 * @property dpmServers List of BackupEngines protecting the container
 * @property extendedInfo Extended Info of the container.
 * @property friendlyName Friendly name of the container.
 * @property healthStatus Status of health of the container.
 * @property protectableObjectType Type of the protectable object associated with this container
 * @property protectedItemCount Number of protected items in the BackupEngine
 * @property protectionStatus Protection status of the container.
 * @property registrationStatus Status of registration of the container with the Recovery Services Vault.
 * @property upgradeAvailable To check if upgrade available
 */
public data class DpmContainerArgs(
    public val backupManagementType: Output<Either<String, BackupManagementType>>? = null,
    public val canReRegister: Output<Boolean>? = null,
    public val containerId: Output<String>? = null,
    public val containerType: Output<String>,
    public val dpmAgentVersion: Output<String>? = null,
    public val dpmServers: Output<List<String>>? = null,
    public val extendedInfo: Output<DPMContainerExtendedInfoArgs>? = null,
    public val friendlyName: Output<String>? = null,
    public val healthStatus: Output<String>? = null,
    public val protectableObjectType: Output<String>? = null,
    public val protectedItemCount: Output<Double>? = null,
    public val protectionStatus: Output<String>? = null,
    public val registrationStatus: Output<String>? = null,
    public val upgradeAvailable: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.DpmContainerArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.DpmContainerArgs =
        com.pulumi.azurenative.recoveryservices.inputs.DpmContainerArgs.builder()
            .backupManagementType(
                backupManagementType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .canReRegister(canReRegister?.applyValue({ args0 -> args0 }))
            .containerId(containerId?.applyValue({ args0 -> args0 }))
            .containerType(containerType.applyValue({ args0 -> args0 }))
            .dpmAgentVersion(dpmAgentVersion?.applyValue({ args0 -> args0 }))
            .dpmServers(dpmServers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .extendedInfo(extendedInfo?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .friendlyName(friendlyName?.applyValue({ args0 -> args0 }))
            .healthStatus(healthStatus?.applyValue({ args0 -> args0 }))
            .protectableObjectType(protectableObjectType?.applyValue({ args0 -> args0 }))
            .protectedItemCount(protectedItemCount?.applyValue({ args0 -> args0 }))
            .protectionStatus(protectionStatus?.applyValue({ args0 -> args0 }))
            .registrationStatus(registrationStatus?.applyValue({ args0 -> args0 }))
            .upgradeAvailable(upgradeAvailable?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DpmContainerArgs].
 */
@PulumiTagMarker
public class DpmContainerArgsBuilder internal constructor() {
    private var backupManagementType: Output<Either<String, BackupManagementType>>? = null

    private var canReRegister: Output<Boolean>? = null

    private var containerId: Output<String>? = null

    private var containerType: Output<String>? = null

    private var dpmAgentVersion: Output<String>? = null

    private var dpmServers: Output<List<String>>? = null

    private var extendedInfo: Output<DPMContainerExtendedInfoArgs>? = null

    private var friendlyName: Output<String>? = null

    private var healthStatus: Output<String>? = null

    private var protectableObjectType: Output<String>? = null

    private var protectedItemCount: Output<Double>? = null

    private var protectionStatus: Output<String>? = null

    private var registrationStatus: Output<String>? = null

    private var upgradeAvailable: Output<Boolean>? = null

    /**
     * @param value Type of backup management for the container.
     */
    @JvmName("bqldatohuvdqukww")
    public suspend fun backupManagementType(`value`: Output<Either<String, BackupManagementType>>) {
        this.backupManagementType = value
    }

    /**
     * @param value Specifies whether the container is re-registrable.
     */
    @JvmName("yxmngocdkbsmwxsm")
    public suspend fun canReRegister(`value`: Output<Boolean>) {
        this.canReRegister = value
    }

    /**
     * @param value ID of container.
     */
    @JvmName("hxkelerynjdhhwbt")
    public suspend fun containerId(`value`: Output<String>) {
        this.containerId = value
    }

    /**
     * @param value Type of the container. The value of this property for: 1. Compute Azure VM is Microsoft.Compute/virtualMachines 2.
     * Classic Compute Azure VM is Microsoft.ClassicCompute/virtualMachines 3. Windows machines (like MAB, DPM etc) is
     * Windows 4. Azure SQL instance is AzureSqlContainer. 5. Storage containers is StorageContainer. 6. Azure workload
     * Backup is VMAppContainer
     * Expected value is 'DPMContainer'.
     */
    @JvmName("resuupavbvrqxrqw")
    public suspend fun containerType(`value`: Output<String>) {
        this.containerType = value
    }

    /**
     * @param value Backup engine Agent version
     */
    @JvmName("rhukotfffynpneif")
    public suspend fun dpmAgentVersion(`value`: Output<String>) {
        this.dpmAgentVersion = value
    }

    /**
     * @param value List of BackupEngines protecting the container
     */
    @JvmName("xhtgvdomdehukuuh")
    public suspend fun dpmServers(`value`: Output<List<String>>) {
        this.dpmServers = value
    }

    @JvmName("merdwqtxqvcumlwe")
    public suspend fun dpmServers(vararg values: Output<String>) {
        this.dpmServers = Output.all(values.asList())
    }

    /**
     * @param values List of BackupEngines protecting the container
     */
    @JvmName("xsufsxtsjwteaodd")
    public suspend fun dpmServers(values: List<Output<String>>) {
        this.dpmServers = Output.all(values)
    }

    /**
     * @param value Extended Info of the container.
     */
    @JvmName("vmogiseagalnndhr")
    public suspend fun extendedInfo(`value`: Output<DPMContainerExtendedInfoArgs>) {
        this.extendedInfo = value
    }

    /**
     * @param value Friendly name of the container.
     */
    @JvmName("phxpbrwjxwihpjjp")
    public suspend fun friendlyName(`value`: Output<String>) {
        this.friendlyName = value
    }

    /**
     * @param value Status of health of the container.
     */
    @JvmName("wpsedsjytubspbun")
    public suspend fun healthStatus(`value`: Output<String>) {
        this.healthStatus = value
    }

    /**
     * @param value Type of the protectable object associated with this container
     */
    @JvmName("bhpvjwgtvobjattk")
    public suspend fun protectableObjectType(`value`: Output<String>) {
        this.protectableObjectType = value
    }

    /**
     * @param value Number of protected items in the BackupEngine
     */
    @JvmName("fhivjavalsmeegfn")
    public suspend fun protectedItemCount(`value`: Output<Double>) {
        this.protectedItemCount = value
    }

    /**
     * @param value Protection status of the container.
     */
    @JvmName("auieisalfjvolhft")
    public suspend fun protectionStatus(`value`: Output<String>) {
        this.protectionStatus = value
    }

    /**
     * @param value Status of registration of the container with the Recovery Services Vault.
     */
    @JvmName("ikdpaiaegockmcmm")
    public suspend fun registrationStatus(`value`: Output<String>) {
        this.registrationStatus = value
    }

    /**
     * @param value To check if upgrade available
     */
    @JvmName("jtvyjrxdobyomuub")
    public suspend fun upgradeAvailable(`value`: Output<Boolean>) {
        this.upgradeAvailable = value
    }

    /**
     * @param value Type of backup management for the container.
     */
    @JvmName("nohrdqfhahrbrkxy")
    public suspend fun backupManagementType(`value`: Either<String, BackupManagementType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Type of backup management for the container.
     */
    @JvmName("ouinublvgjkslipp")
    public fun backupManagementType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, BackupManagementType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Type of backup management for the container.
     */
    @JvmName("xwgfhhtteardgycg")
    public fun backupManagementType(`value`: BackupManagementType) {
        val toBeMapped = Either.ofRight<String, BackupManagementType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Specifies whether the container is re-registrable.
     */
    @JvmName("lhwpcjllciyisoeh")
    public suspend fun canReRegister(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.canReRegister = mapped
    }

    /**
     * @param value ID of container.
     */
    @JvmName("mdurvrhqbmbjtqvu")
    public suspend fun containerId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.containerId = mapped
    }

    /**
     * @param value Type of the container. The value of this property for: 1. Compute Azure VM is Microsoft.Compute/virtualMachines 2.
     * Classic Compute Azure VM is Microsoft.ClassicCompute/virtualMachines 3. Windows machines (like MAB, DPM etc) is
     * Windows 4. Azure SQL instance is AzureSqlContainer. 5. Storage containers is StorageContainer. 6. Azure workload
     * Backup is VMAppContainer
     * Expected value is 'DPMContainer'.
     */
    @JvmName("pajqrqapqfsklddf")
    public suspend fun containerType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.containerType = mapped
    }

    /**
     * @param value Backup engine Agent version
     */
    @JvmName("unprpvbcqcchnxlf")
    public suspend fun dpmAgentVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dpmAgentVersion = mapped
    }

    /**
     * @param value List of BackupEngines protecting the container
     */
    @JvmName("aacultcvffqmkxxn")
    public suspend fun dpmServers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dpmServers = mapped
    }

    /**
     * @param values List of BackupEngines protecting the container
     */
    @JvmName("egedmrxqvsytycfg")
    public suspend fun dpmServers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dpmServers = mapped
    }

    /**
     * @param value Extended Info of the container.
     */
    @JvmName("udgeyvtfwpsjuqft")
    public suspend fun extendedInfo(`value`: DPMContainerExtendedInfoArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.extendedInfo = mapped
    }

    /**
     * @param argument Extended Info of the container.
     */
    @JvmName("glofcitighrhmhaj")
    public suspend
    fun extendedInfo(argument: suspend DPMContainerExtendedInfoArgsBuilder.() -> Unit) {
        val toBeMapped = DPMContainerExtendedInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.extendedInfo = mapped
    }

    /**
     * @param value Friendly name of the container.
     */
    @JvmName("hunkcgfnmhnnldnv")
    public suspend fun friendlyName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.friendlyName = mapped
    }

    /**
     * @param value Status of health of the container.
     */
    @JvmName("hbqtoeyiibfeeeya")
    public suspend fun healthStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.healthStatus = mapped
    }

    /**
     * @param value Type of the protectable object associated with this container
     */
    @JvmName("aqymteyyawcdcuns")
    public suspend fun protectableObjectType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protectableObjectType = mapped
    }

    /**
     * @param value Number of protected items in the BackupEngine
     */
    @JvmName("fkutignwsovllbhe")
    public suspend fun protectedItemCount(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protectedItemCount = mapped
    }

    /**
     * @param value Protection status of the container.
     */
    @JvmName("wvarjxpgygqhvkrn")
    public suspend fun protectionStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protectionStatus = mapped
    }

    /**
     * @param value Status of registration of the container with the Recovery Services Vault.
     */
    @JvmName("kaxrhfkbicyoeapo")
    public suspend fun registrationStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.registrationStatus = mapped
    }

    /**
     * @param value To check if upgrade available
     */
    @JvmName("olcroxqkbdbinhrk")
    public suspend fun upgradeAvailable(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.upgradeAvailable = mapped
    }

    internal fun build(): DpmContainerArgs = DpmContainerArgs(
        backupManagementType = backupManagementType,
        canReRegister = canReRegister,
        containerId = containerId,
        containerType = containerType ?: throw PulumiNullFieldException("containerType"),
        dpmAgentVersion = dpmAgentVersion,
        dpmServers = dpmServers,
        extendedInfo = extendedInfo,
        friendlyName = friendlyName,
        healthStatus = healthStatus,
        protectableObjectType = protectableObjectType,
        protectedItemCount = protectedItemCount,
        protectionStatus = protectionStatus,
        registrationStatus = registrationStatus,
        upgradeAvailable = upgradeAvailable,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/DpmContainerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.DpmContainerArgs.builder
import com.pulumi.azurenative.recoveryservices.kotlin.enums.BackupManagementType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * DPM workload-specific protection container.
 * @property backupManagementType Type of backup management for the container.
 * @property canReRegister Specifies whether the container is re-registrable.
 * @property containerId ID of container.
 * @property containerType Type of the container. The value of this property for: 1. Compute Azure VM is Microsoft.Compute/virtualMachines 2.
 * Classic Compute Azure VM is Microsoft.ClassicCompute/virtualMachines 3. Windows machines (like MAB, DPM etc) is
 * Windows 4. Azure SQL instance is AzureSqlContainer. 5. Storage containers is StorageContainer. 6. Azure workload
 * Backup is VMAppContainer
 * Expected value is 'DPMContainer'.
 * @property dpmAgentVersion Backup engine Agent version
 * @property dpmServers List of BackupEngines protecting the container
 * @property extendedInfo Extended Info of the container.
 * @property friendlyName Friendly name of the container.
 * @property healthStatus Status of health of the container.
 * @property protectableObjectType Type of the protectable object associated with this container
 * @property protectedItemCount Number of protected items in the BackupEngine
 * @property protectionStatus Protection status of the container.
 * @property registrationStatus Status of registration of the container with the Recovery Services Vault.
 * @property upgradeAvailable To check if upgrade available
 */
public data class DpmContainerArgs(
    public val backupManagementType: Output<Either<String, BackupManagementType>>? = null,
    public val canReRegister: Output<Boolean>? = null,
    public val containerId: Output<String>? = null,
    public val containerType: Output<String>,
    public val dpmAgentVersion: Output<String>? = null,
    public val dpmServers: Output<List<String>>? = null,
    public val extendedInfo: Output<DPMContainerExtendedInfoArgs>? = null,
    public val friendlyName: Output<String>? = null,
    public val healthStatus: Output<String>? = null,
    public val protectableObjectType: Output<String>? = null,
    public val protectedItemCount: Output<Double>? = null,
    public val protectionStatus: Output<String>? = null,
    public val registrationStatus: Output<String>? = null,
    public val upgradeAvailable: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.DpmContainerArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.DpmContainerArgs =
        com.pulumi.azurenative.recoveryservices.inputs.DpmContainerArgs.builder()
            .backupManagementType(
                backupManagementType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .canReRegister(canReRegister?.applyValue({ args0 -> args0 }))
            .containerId(containerId?.applyValue({ args0 -> args0 }))
            .containerType(containerType.applyValue({ args0 -> args0 }))
            .dpmAgentVersion(dpmAgentVersion?.applyValue({ args0 -> args0 }))
            .dpmServers(dpmServers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .extendedInfo(extendedInfo?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .friendlyName(friendlyName?.applyValue({ args0 -> args0 }))
            .healthStatus(healthStatus?.applyValue({ args0 -> args0 }))
            .protectableObjectType(protectableObjectType?.applyValue({ args0 -> args0 }))
            .protectedItemCount(protectedItemCount?.applyValue({ args0 -> args0 }))
            .protectionStatus(protectionStatus?.applyValue({ args0 -> args0 }))
            .registrationStatus(registrationStatus?.applyValue({ args0 -> args0 }))
            .upgradeAvailable(upgradeAvailable?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DpmContainerArgs].
 */
@PulumiTagMarker
public class DpmContainerArgsBuilder internal constructor() {
    private var backupManagementType: Output<Either<String, BackupManagementType>>? = null

    private var canReRegister: Output<Boolean>? = null

    private var containerId: Output<String>? = null

    private var containerType: Output<String>? = null

    private var dpmAgentVersion: Output<String>? = null

    private var dpmServers: Output<List<String>>? = null

    private var extendedInfo: Output<DPMContainerExtendedInfoArgs>? = null

    private var friendlyName: Output<String>? = null

    private var healthStatus: Output<String>? = null

    private var protectableObjectType: Output<String>? = null

    private var protectedItemCount: Output<Double>? = null

    private var protectionStatus: Output<String>? = null

    private var registrationStatus: Output<String>? = null

    private var upgradeAvailable: Output<Boolean>? = null

    /**
     * @param value Type of backup management for the container.
     */
    @JvmName("klxfylixxlcwxeqa")
    public suspend fun backupManagementType(`value`: Output<Either<String, BackupManagementType>>) {
        this.backupManagementType = value
    }

    /**
     * @param value Specifies whether the container is re-registrable.
     */
    @JvmName("vvxeqmotbahwecka")
    public suspend fun canReRegister(`value`: Output<Boolean>) {
        this.canReRegister = value
    }

    /**
     * @param value ID of container.
     */
    @JvmName("cswijobkgnqalxjv")
    public suspend fun containerId(`value`: Output<String>) {
        this.containerId = value
    }

    /**
     * @param value Type of the container. The value of this property for: 1. Compute Azure VM is Microsoft.Compute/virtualMachines 2.
     * Classic Compute Azure VM is Microsoft.ClassicCompute/virtualMachines 3. Windows machines (like MAB, DPM etc) is
     * Windows 4. Azure SQL instance is AzureSqlContainer. 5. Storage containers is StorageContainer. 6. Azure workload
     * Backup is VMAppContainer
     * Expected value is 'DPMContainer'.
     */
    @JvmName("hqvyhrksqmalsqsi")
    public suspend fun containerType(`value`: Output<String>) {
        this.containerType = value
    }

    /**
     * @param value Backup engine Agent version
     */
    @JvmName("fwyqqrkvqmdxgusf")
    public suspend fun dpmAgentVersion(`value`: Output<String>) {
        this.dpmAgentVersion = value
    }

    /**
     * @param value List of BackupEngines protecting the container
     */
    @JvmName("qeokxyvyxbkqrtaq")
    public suspend fun dpmServers(`value`: Output<List<String>>) {
        this.dpmServers = value
    }

    @JvmName("yvthilbmstedqpox")
    public suspend fun dpmServers(vararg values: Output<String>) {
        this.dpmServers = Output.all(values.asList())
    }

    /**
     * @param values List of BackupEngines protecting the container
     */
    @JvmName("ehgsupqcwqwihmhu")
    public suspend fun dpmServers(values: List<Output<String>>) {
        this.dpmServers = Output.all(values)
    }

    /**
     * @param value Extended Info of the container.
     */
    @JvmName("insxdrhqlkyndahd")
    public suspend fun extendedInfo(`value`: Output<DPMContainerExtendedInfoArgs>) {
        this.extendedInfo = value
    }

    /**
     * @param value Friendly name of the container.
     */
    @JvmName("ruhmljbhkdvvtdoq")
    public suspend fun friendlyName(`value`: Output<String>) {
        this.friendlyName = value
    }

    /**
     * @param value Status of health of the container.
     */
    @JvmName("annrmyrayqktorbv")
    public suspend fun healthStatus(`value`: Output<String>) {
        this.healthStatus = value
    }

    /**
     * @param value Type of the protectable object associated with this container
     */
    @JvmName("ftqopbdlfscirxfi")
    public suspend fun protectableObjectType(`value`: Output<String>) {
        this.protectableObjectType = value
    }

    /**
     * @param value Number of protected items in the BackupEngine
     */
    @JvmName("mekeacxonqvbduxe")
    public suspend fun protectedItemCount(`value`: Output<Double>) {
        this.protectedItemCount = value
    }

    /**
     * @param value Protection status of the container.
     */
    @JvmName("uohgkmgrbufhqiip")
    public suspend fun protectionStatus(`value`: Output<String>) {
        this.protectionStatus = value
    }

    /**
     * @param value Status of registration of the container with the Recovery Services Vault.
     */
    @JvmName("eegnysmecctkljjh")
    public suspend fun registrationStatus(`value`: Output<String>) {
        this.registrationStatus = value
    }

    /**
     * @param value To check if upgrade available
     */
    @JvmName("ucfcrodkderioale")
    public suspend fun upgradeAvailable(`value`: Output<Boolean>) {
        this.upgradeAvailable = value
    }

    /**
     * @param value Type of backup management for the container.
     */
    @JvmName("biicubbqudncfmsu")
    public suspend fun backupManagementType(`value`: Either<String, BackupManagementType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Type of backup management for the container.
     */
    @JvmName("ofmggghcdeqvoshb")
    public fun backupManagementType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, BackupManagementType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Type of backup management for the container.
     */
    @JvmName("havltlwtygfegdxx")
    public fun backupManagementType(`value`: BackupManagementType) {
        val toBeMapped = Either.ofRight<String, BackupManagementType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.backupManagementType = mapped
    }

    /**
     * @param value Specifies whether the container is re-registrable.
     */
    @JvmName("tvtprljefsmrwwhw")
    public suspend fun canReRegister(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.canReRegister = mapped
    }

    /**
     * @param value ID of container.
     */
    @JvmName("vuhnnvhqfosqcxuv")
    public suspend fun containerId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.containerId = mapped
    }

    /**
     * @param value Type of the container. The value of this property for: 1. Compute Azure VM is Microsoft.Compute/virtualMachines 2.
     * Classic Compute Azure VM is Microsoft.ClassicCompute/virtualMachines 3. Windows machines (like MAB, DPM etc) is
     * Windows 4. Azure SQL instance is AzureSqlContainer. 5. Storage containers is StorageContainer. 6. Azure workload
     * Backup is VMAppContainer
     * Expected value is 'DPMContainer'.
     */
    @JvmName("lghajgrxvrvjqgfq")
    public suspend fun containerType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.containerType = mapped
    }

    /**
     * @param value Backup engine Agent version
     */
    @JvmName("njwuxvglgfsrpgid")
    public suspend fun dpmAgentVersion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dpmAgentVersion = mapped
    }

    /**
     * @param value List of BackupEngines protecting the container
     */
    @JvmName("laydfnooreikgyqm")
    public suspend fun dpmServers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dpmServers = mapped
    }

    /**
     * @param values List of BackupEngines protecting the container
     */
    @JvmName("pcapivauymxxucyr")
    public suspend fun dpmServers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dpmServers = mapped
    }

    /**
     * @param value Extended Info of the container.
     */
    @JvmName("icydigobalwksgfe")
    public suspend fun extendedInfo(`value`: DPMContainerExtendedInfoArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.extendedInfo = mapped
    }

    /**
     * @param argument Extended Info of the container.
     */
    @JvmName("axgckxwlrmfhycwm")
    public suspend
    fun extendedInfo(argument: suspend DPMContainerExtendedInfoArgsBuilder.() -> Unit) {
        val toBeMapped = DPMContainerExtendedInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.extendedInfo = mapped
    }

    /**
     * @param value Friendly name of the container.
     */
    @JvmName("nbymgifqwvbvvjfc")
    public suspend fun friendlyName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.friendlyName = mapped
    }

    /**
     * @param value Status of health of the container.
     */
    @JvmName("onbqqdyvdwinlpbu")
    public suspend fun healthStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.healthStatus = mapped
    }

    /**
     * @param value Type of the protectable object associated with this container
     */
    @JvmName("uycqvnwvurvmepst")
    public suspend fun protectableObjectType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protectableObjectType = mapped
    }

    /**
     * @param value Number of protected items in the BackupEngine
     */
    @JvmName("oykwodcnirpxoksk")
    public suspend fun protectedItemCount(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protectedItemCount = mapped
    }

    /**
     * @param value Protection status of the container.
     */
    @JvmName("yxervfurftycqjub")
    public suspend fun protectionStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protectionStatus = mapped
    }

    /**
     * @param value Status of registration of the container with the Recovery Services Vault.
     */
    @JvmName("siqjegyrapyhdjcq")
    public suspend fun registrationStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.registrationStatus = mapped
    }

    /**
     * @param value To check if upgrade available
     */
    @JvmName("pnlbijdbhtoapuju")
    public suspend fun upgradeAvailable(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.upgradeAvailable = mapped
    }

    internal fun build(): DpmContainerArgs = DpmContainerArgs(
        backupManagementType = backupManagementType,
        canReRegister = canReRegister,
        containerId = containerId,
        containerType = containerType ?: throw PulumiNullFieldException("containerType"),
        dpmAgentVersion = dpmAgentVersion,
        dpmServers = dpmServers,
        extendedInfo = extendedInfo,
        friendlyName = friendlyName,
        healthStatus = healthStatus,
        protectableObjectType = protectableObjectType,
        protectedItemCount = protectedItemCount,
        protectionStatus = protectionStatus,
        registrationStatus = registrationStatus,
        upgradeAvailable = upgradeAvailable,
    )
}
